aboutsummaryrefslogtreecommitdiffstats
path: root/epan/dissectors/packet-zep.c
diff options
context:
space:
mode:
authorGuy Harris <guy@alum.mit.edu>2019-02-27 09:38:14 -0800
committerGuy Harris <guy@alum.mit.edu>2019-02-27 17:38:52 +0000
commitec6cdc81bd07687d4e127435b1d5f147c35e84ca (patch)
tree7662e35a45389e3ffa1eabedff5463c6d0a70956 /epan/dissectors/packet-zep.c
parente3ecc0692c2d5d158504d65273498188c73dfde4 (diff)
More "It's not a CRC, it's metadata".
Also ask, in a comment, how long the CRC is if we *do* have a CRC rather than metadata. Change-Id: I92da4d3ade9b69f65b39ea058915f3ee4530b786 Reviewed-on: https://code.wireshark.org/review/32237 Reviewed-by: Guy Harris <guy@alum.mit.edu>
Diffstat (limited to 'epan/dissectors/packet-zep.c')
-rw-r--r--epan/dissectors/packet-zep.c14
1 files changed, 8 insertions, 6 deletions
diff --git a/epan/dissectors/packet-zep.c b/epan/dissectors/packet-zep.c
index 5b7281bc0d..50b28d73a3 100644
--- a/epan/dissectors/packet-zep.c
+++ b/epan/dissectors/packet-zep.c
@@ -86,7 +86,7 @@ static dissector_handle_t zep_handle;
/* Subdissector handles */
static dissector_handle_t ieee802154_handle;
-static dissector_handle_t ieee802154_ccfcs_handle;
+static dissector_handle_t ieee802154_cc24xx_handle;
/*FUNCTION:------------------------------------------------------
* NAME
@@ -213,15 +213,17 @@ static int dissect_zep(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void
/* Determine which dissector to call next. */
if (lqi_mode) {
- /* CRC present, use standard IEEE dissector. */
+ /* CRC present, use standard IEEE dissector.
+ * XXX - 2-octet or 4-octet CRC?
+ */
next_dissector = ieee802154_handle;
}
else {
- /* ChipCon compliant FCS present. */
- next_dissector = ieee802154_ccfcs_handle;
+ /* ChipCon/TI CC24xx-compliant metadata present, CRC absent */
+ next_dissector = ieee802154_cc24xx_handle;
}
- /* Call the IEEE 802.15.4 dissector */
+ /* Call the appropriate IEEE 802.15.4 dissector */
if (!((version>=2) && (type==ZEP_V2_TYPE_ACK))) {
next_tvb = tvb_new_subset_length(tvb, zep_header_len, ieee_packet_len);
if (next_dissector != NULL) {
@@ -332,7 +334,7 @@ void proto_reg_handoff_zep(void)
if ( !(h = find_dissector("wpan_cc24xx")) ) { /* Try use built-in 802.15.4 (Chipcon) dissector */
h = find_dissector("ieee802154_ccfcs"); /* otherwise use older 802.15.4 (Chipcon) plugin dissector */
}
- ieee802154_ccfcs_handle = h;
+ ieee802154_cc24xx_handle = h;
dissector_add_uint("udp.port", ZEP_DEFAULT_PORT, zep_handle);
} /* proto_reg_handoff_zep */